@@ -245,11 +245,18 @@ def pytest_addoption(parser):
         dest="ignore_addon_errors",
         help=("Path to file where list of addon related errors are suppressed."),
     )
+    group.addoption(
+        "--ignore-errors-not-related-to-addon",
+        action="store",
+        dest="ignore_errors_not_related_to_addon",
+        help=("Path to file where list of errors not related to addon are suppressed."),
+    )
     group.addoption(
         "--requirement-test",
-        action="store_true",
+        action="store",
         dest="requirement_test",
-        help=("Default false use if requirement tests need to be run"),
+        default="None",
+        help="Default None, path to --requirement-test files if requirement tests need to be run",
     )
     group.addoption(
         "--splunk-uf-host",
@@ -279,6 +286,34 @@ def pytest_addoption(parser):
         default="Chang3d!",
         help="Password of the Universal Forwarder user",
     )
+    group.addoption(
+        "--event-file-path",
+        action="store",
+        dest="event_path",
+        help="Path to tokenised event directory",
+        default="events.pickle",
+    )
+    group.addoption(
+        "--tokenized-event-source",
+        action="store",
+        dest="tokenized_event_source",
+        help="One of (new|pregenerated|store_new)",
+        default="store_new",
+    )
+    group.addoption(
+        "--ingest-events",
+        action="store",
+        dest="ingest_events",
+        help="Should ingest events or not (True|False)",
+        default="True",
+    )
+    group.addoption(
+        "--execute-test",
+        action="store",
+        dest="execute_test",
+        help="Should execute test or not (True|False)",
+        default="True",
+    )
 
 
 @pytest.fixture(scope="session")
@@ -334,24 +369,37 @@ def splunk_search_util(splunk, request):
 
     return search_util
 
+
 @pytest.fixture(scope="session")
 def ignore_internal_errors(request):
     """
-    This fixture generates a common list of errors which are suppossed 
+    This fixture generates a common list of errors which are suppossed
     to be ignored in test_splunk_internal_errors.
 
     Returns:
         dict: List of the strings to be ignored in test_splunk_internal_errors
     """
     error_list = []
-    splunk_error_file_path = os.path.join(os.path.dirname(os.path.abspath(__file__)),".ignore_splunk_internal_errors")
+    splunk_error_file_path = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), ".ignore_splunk_internal_errors"
+    )
     with open(splunk_error_file_path) as splunk_errors:
         error_list = [each_error.strip() for each_error in splunk_errors.readlines()]
     if request.config.getoption("ignore_addon_errors"):
         addon_error_file_path = request.config.getoption("ignore_addon_errors")
         if os.path.exists(addon_error_file_path):
             with open(addon_error_file_path, "r") as addon_errors:
-                error_list.extend([each_error.strip() for each_error in addon_errors.readlines()])
+                error_list.extend(
+                    [each_error.strip() for each_error in addon_errors.readlines()]
+                )
+    if request.config.getoption("ignore_errors_not_related_to_addon"):
+        file_path = request.config.getoption("ignore_errors_not_related_to_addon")
+        if os.path.exists(file_path):
+            with open(file_path, "r") as non_ta_errors:
+                error_list.extend(
+                    [each_error.strip() for each_error in non_ta_errors.readlines()]
+                )
+
     yield error_list
 
 
@@ -375,7 +423,9 @@ def splunk(request, file_system_prerequisite):
             config = configparser.ConfigParser()
             config.read(
                 os.path.join(
-                    request.config.getoption("splunk_app"), "default", "app.conf",
+                    request.config.getoption("splunk_app"),
+                    "default",
+                    "app.conf",
                 )
             )
             os.environ["SPLUNK_APP_ID"] = config["package"]["id"]
@@ -415,6 +465,7 @@ def sc4s(request):
 
     yield sc4s
 
+
 @pytest.fixture(scope="session")
 def uf(request):
     """
@@ -434,6 +485,7 @@ def uf(request):
         raise Exception
     yield uf
 
+
 @pytest.fixture(scope="session")
 def uf_docker(docker_services, tmp_path_factory, worker_id, request):
     """
@@ -459,6 +511,7 @@ def uf_docker(docker_services, tmp_path_factory, worker_id, request):
         sleep(1)
     return uf_info
 
+
 @pytest.fixture(scope="session")
 def uf_external(request):
     """
@@ -516,7 +569,9 @@ def splunk_docker(
     )
 
     docker_services.wait_until_responsive(
-        timeout=180.0, pause=0.5, check=lambda: is_responsive_splunk(splunk_info),
+        timeout=180.0,
+        pause=0.5,
+        check=lambda: is_responsive_splunk(splunk_info),
     )
 
     return splunk_info
@@ -542,7 +597,9 @@ def splunk_external(request):
     if not request.config.getoption("splunk_forwarder_host"):
         splunk_info["forwarder_host"] = splunk_info.get("host")
     else:
-        splunk_info["forwarder_host"] = request.config.getoption("splunk_forwarder_host")
+        splunk_info["forwarder_host"] = request.config.getoption(
+            "splunk_forwarder_host"
+        )
 
     for _ in range(RESPONSIVE_SPLUNK_TIMEOUT):
         if is_responsive_splunk(splunk_info):
@@ -587,7 +644,7 @@ def sc4s_docker(docker_services, tmp_path_factory, worker_id):
 def sc4s_external(request):
     """
     Provides IP of the sc4s server and related ports based on pytest-args(splunk_type)
-    TODO: For splunk_type=external, data will not be ingested as 
+    TODO: For splunk_type=external, data will not be ingested as
     manual configurations are required.
     """
     ports = {514: int(request.config.getoption("sc4s_port"))}
@@ -653,6 +710,8 @@ def splunk_ingest_data(request, splunk_hec_uri, sc4s, uf, splunk_events_cleanup)
     TODO:
         For splunk_type=external, data will not be ingested as manual configurations are required.
     """
+    if request.config.getoption("ingest_events").lower() in ["n", "no", "false", "f"]:
+        return
     global PYTEST_XDIST_TESTRUNUID
     if (
         "PYTEST_XDIST_WORKER" not in os.environ
@@ -674,7 +733,12 @@ def splunk_ingest_data(request, splunk_hec_uri, sc4s, uf, splunk_events_cleanup)
         thread_count = int(request.config.getoption("thread_count"))
         store_events = request.config.getoption("store_events")
         IngestorHelper.ingest_events(
-            ingest_meta_data, addon_path, config_path, thread_count, store_events, run_requirement_test
+            ingest_meta_data,
+            addon_path,
+            config_path,
+            thread_count,
+            store_events,
+            run_requirement_test,
         )
         sleep(50)
         if "PYTEST_XDIST_WORKER" in os.environ:
@@ -704,6 +768,7 @@ def splunk_events_cleanup(request, splunk_search_util):
     else:
         LOGGER.info("Events cleanup was disabled.")
 
+
 @pytest.fixture(scope="session")
 def file_system_prerequisite():
     """
@@ -720,6 +785,7 @@ def file_system_prerequisite():
             shutil.rmtree(monitor_dir, ignore_errors=True)
         os.mkdir(monitor_dir)
 
+
 def is_responsive_uf(uf):
     """
     Verify if the management port of Universal Forwarder is responsive or not
@@ -732,7 +798,8 @@ def is_responsive_uf(uf):
     """
     try:
         LOGGER.info(
-            "Trying to connect Universal Forwarder instance...  splunk=%s", json.dumps(uf),
+            "Trying to connect Universal Forwarder instance...  splunk=%s",
+            json.dumps(uf),
         )
         client.connect(
             username=uf["uf_username"],
@@ -745,10 +812,12 @@ def is_responsive_uf(uf):
         return True
     except Exception as e:
         LOGGER.warning(
-            "Could not connect to Universal Forwarder Instance. Will try again. exception=%s", str(e),
+            "Could not connect to Universal Forwarder Instance. Will try again. exception=%s",
+            str(e),
         )
         return False
 
+
 def is_responsive_splunk(splunk):
     """
     Verify if the management port of Splunk is responsive or not
@@ -761,7 +830,8 @@ def is_responsive_splunk(splunk):
     """
     try:
         LOGGER.info(
-            "Trying to connect Splunk instance...  splunk=%s", json.dumps(splunk),
+            "Trying to connect Splunk instance...  splunk=%s",
+            json.dumps(splunk),
         )
         client.connect(
             username=splunk["username"],
@@ -774,10 +844,12 @@ def is_responsive_splunk(splunk):
         return True
     except Exception as e:
         LOGGER.warning(
-            "Could not connect to Splunk Instance. Will try again. exception=%s", str(e),
+            "Could not connect to Splunk Instance. Will try again. exception=%s",
+            str(e),
         )
         return False
 
+
 def is_responsive_hec(request, splunk):
     """
     Verify if the hec port of Splunk is responsive or not
@@ -790,24 +862,26 @@ def is_responsive_hec(request, splunk):
     """
     try:
         LOGGER.info(
-            "Trying to connect Splunk HEC...  splunk=%s", json.dumps(splunk),
+            "Trying to connect Splunk HEC...  splunk=%s",
+            json.dumps(splunk),
         )
         session_headers = {
             "Authorization": f'Splunk {request.config.getoption("splunk_hec_token")}'
         }
         response = requests.get(
-                f'{request.config.getoption("splunk_hec_scheme")}://{splunk["forwarder_host"]}:{splunk["port_hec"]}/services/collector/health/1.0',
-                verify=False,
-            )
+            f'{request.config.getoption("splunk_hec_scheme")}://{splunk["forwarder_host"]}:{splunk["port_hec"]}/services/collector/health/1.0',
+            verify=False,
+        )
         LOGGER.debug("Status code: {}".format(response.status_code))
-        if response.status_code in (200,201):
+        if response.status_code in (200, 201):
             LOGGER.info("Splunk HEC is responsive.")
             return True
         else:
             return False
     except Exception as e:
         LOGGER.warning(
-            "Could not connect to Splunk HEC. Will try again. exception=%s", str(e),
+            "Could not connect to Splunk HEC. Will try again. exception=%s",
+            str(e),
         )
         return False
 
@@ -831,7 +905,8 @@ def is_responsive(url):
             return True
     except ConnectionError as e:
         LOGGER.warning(
-            "Could not connect to url yet. Will try again. exception=%s", str(e),
+            "Could not connect to url yet. Will try again. exception=%s",
+            str(e),
         )
         return False
 
