@@ -7,6 +7,7 @@ import json
 from ..addon_parser import Field
 from ..addon_parser import PropsParser
 
+
 class FieldBank(object):
     """
     Supports field_bank: List of fields with patterns and expected
@@ -14,8 +15,8 @@ class FieldBank(object):
 
     Steps to use:
 
-    1. Create a json file with the list of fields. 
-    
+    1. Create a json file with the list of fields.
+
         Example::
 
             {
@@ -35,8 +36,8 @@ class FieldBank(object):
             :header: Parameter, Description
 
             condition, A filtering SPL command.
-            validity, An EVAL statement. Filter out invalid value of a field 
-            expected_fields, List of expected_fields 
+            validity, An EVAL statement. Filter out invalid value of a field
+            expected_fields, List of expected_fields
             negative_fields, The list of values the field should not have
 
         supported stanza_type:
@@ -44,7 +45,7 @@ class FieldBank(object):
             1. source
             2. sourcetype
 
-    2. Provide path of the json file with --field-bank=path parameter 
+    2. Provide path of the json file with --field-bank=path parameter
     """
 
     @classmethod
@@ -64,19 +65,19 @@ class FieldBank(object):
             for each_stanza in stanza_list:
                 if each_stanza.startswith("host::"):
                     continue
-                field_list = Field.parse_fields(stanza_list[each_stanza]) 
+                field_list = Field.parse_fields(stanza_list[each_stanza])
                 if each_stanza.startswith("source::"):
                     for each_source in PropsParser.get_list_of_sources(each_stanza):
                         yield {
                             "stanza": each_source,
                             "stanza_type": "source",
                             "classname": "field_bank",
-                            "fields": field_list
+                            "fields": field_list,
                         }
                 else:
-                    yield { 
+                    yield {
                         "stanza": each_stanza,
                         "stanza_type": "sourcetype",
                         "classname": "field_bank",
-                        "fields": field_list
+                        "fields": field_list,
                     }
